<?php

namespace SGalinski\SgMail\Service;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Core\TypoScript\TypoScriptService;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Utility\VersionNumberUtility;
use TYPO3\CMS\Extbase\Configuration\BackendConfigurationManager;
use TYPO3\CMS\Extbase\Object\ObjectManager;

/**
 * Returns the typoscript setup based on the page id
 *
 */
class TypoScriptSettingsService implements SingletonInterface {
	/**
	 * @var array
	 */
	protected static $typoScriptCache = [];

	/**
	 * Returns the typoscript settings of a given page and extension
	 *
	 * @param int $pageId
	 * @param string $extensionKey
	 * @return array
	 */
	public function getSettings($pageId, $extensionKey): array {
		$pageId = (int) $pageId;
		$cacheHash = $extensionKey . $pageId;
		if (!isset(self::$typoScriptCache[$cacheHash])) {
			$tmpId = $_POST['id'];
			$_POST['id'] = $pageId;
			if (version_compare(VersionNumberUtility::getCurrentTypo3Version(), '10.4.0', '<')) {
				$objectManager = GeneralUtility::makeInstance(ObjectManager::class);
				/** @var TypoScriptService $typoScriptService */
				$typoScriptService = $objectManager->get(TypoScriptService::class);
				/** @var BackendConfigurationManager $configurationManager */
				$configurationManager = $objectManager->get(BackendConfigurationManager::class);
			} else {
				$typoScriptService = GeneralUtility::makeInstance(TypoScriptService::class);
				$configurationManager = GeneralUtility::makeInstance(BackendConfigurationManager::class);
			}

			self::$typoScriptCache[$cacheHash] = $typoScriptService->convertTypoScriptArrayToPlainArray(
				(array) $configurationManager->getTypoScriptSetup()['module.'][$extensionKey . '.']['settings.']
			);
			$_POST['id'] = $tmpId;
		}

		return self::$typoScriptCache[$cacheHash];
	}
}
